@@ -1,11 +1,12 @@
 import logging
 import re
 from collections import defaultdict
-from dataclasses import _MISSING_TYPE, dataclass, is_dataclass
+from dataclasses import _MISSING_TYPE, dataclass, field, is_dataclass
 from os import environ
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Type, get_type_hints
 
+import pytz
 import yaml
 from yaml.loader import SafeLoader
 
@@ -118,7 +119,11 @@ def load_settings(  # noqa: C901
         else:
             if env_value := environ.get(env_path):
                 config_value = env_value
-            if not isinstance(config_value, option_type):
+            if (cast_func := option.metadata.get("cast")) and isinstance(
+                config_value, str
+            ):
+                config_value = cast_func(config_value)
+            elif not isinstance(config_value, option_type):
                 config_value = transform(option_type, config_value)
         if config_value is None:
             if not isinstance(option.default, _MISSING_TYPE):
@@ -169,6 +174,7 @@ class MetaTraderSettings:
     password: str
     path: Path
     server: str
+    timezone: pytz.tzinfo.StaticTzInfo = field(metadata={"cast": pytz.timezone})
 
 
 @dataclass
